==> haskell-setenv-0.1.1.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-setenv.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: setenv
version: 0.1.1.3
id: setenv-0.1.1.3-BDKZw88F6QnHLVIxtB3r29
key: setenv-0.1.1.3-BDKZw88F6QnHLVIxtB3r29
license: MIT
copyright: (c) 2012-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
synopsis: A cross-platform library for setting environment variables
description:
    A cross-platform library for setting environment variables
    .
    Note: Since @base- 4.7.0.0@ the functions @setEnv@ and
    @unsetEnv@ are provided by @System.Environment@.
    @System.SetEnv@ merily re-exports those functions when built
    with @base >= 4.7@.
category: System
author: Simon Hengel <sol@typeful.net>
exposed: True
indefinite: False
exposed-modules:
    System.SetEnv
abi: 221ec96ab272bbe35b12c27562404c0e
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/setenv-0.1.1.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/setenv-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/setenv-0.1.1.3
hs-libraries: HSsetenv-0.1.1.3-BDKZw88F6QnHLVIxtB3r29
depends:
    base-4.10.0.0 unix-2.7.2.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             unix-2.7.2.2=7af8630098b53e228272ffaea5bacf62
haddock-interfaces: /usr/share/doc/haskell-setenv/html/setenv.haddock
haddock-html: /usr/share/doc/haskell-setenv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-setenv-0.1.1.3-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-setenv.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: setenv
version: 0.1.1.3
id: setenv-0.1.1.3-4FEJPUU51wbJmlhCSZScDf
key: setenv-0.1.1.3-4FEJPUU51wbJmlhCSZScDf
license: MIT
copyright: (c) 2012-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
synopsis: A cross-platform library for setting environment variables
description:
    A cross-platform library for setting environment variables
    .
    Note: Since @base- 4.7.0.0@ the functions @setEnv@ and
    @unsetEnv@ are provided by @System.Environment@.
    @System.SetEnv@ merily re-exports those functions when built
    with @base >= 4.7@.
category: System
author: Simon Hengel <sol@typeful.net>
exposed: True
indefinite: False
exposed-modules:
    System.SetEnv
abi: 47f2e6fa4c7735b4d7b72a0a7181676d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/setenv-0.1.1.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/setenv-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/setenv-0.1.1.3
hs-libraries: HSsetenv-0.1.1.3-4FEJPUU51wbJmlhCSZScDf
depends:
    base-4.10.1.0 unix-2.7.2.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
haddock-interfaces: /usr/share/doc/haskell-setenv/html/setenv.haddock
haddock-html: /usr/share/doc/haskell-setenv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
